# MVPLN-VAR-dfev.R
#
# Computes the impulse responses for each of the regimes
#
# 20100505 : Initial version

library(MSBVAR)

# Load the posterior irf samples
load("MVPLN-VAR-monthly-dynamics.RData")

# Here's a function for the IRFs -- this is basically a modification
# of dfev.VAR from the MSBVAR package.  This initial function does a
# dfev for a single posterior draw and returns it as a proportion
# measure in a matrix.

MVPLN.dfev <- function(x, h, m)
{
    # Put the IRF back into an array
    xtmp <- array(x, c(h, m, m))

    # Find the variances
    cimp <- apply(xtmp^2, c(2,3), cumsum)

    # Rescale
    vimp <- apply(cimp, c(1,3), sum)

    # Compute the dfev
    fevd <- sapply(1:m, function(i) { cimp[,,i]/vimp[,i]} )

    return(fevd)
}

# Now compute the dfev and find their means
d1 <- rowSums(apply(irf1, 1, MVPLN.dfev, h=12, m=4))/100000
d2 <- rowSums(apply(irf2, 1, MVPLN.dfev, h=12, m=4))/100000
d3 <- rowSums(apply(irf3, 1, MVPLN.dfev, h=12, m=4))/100000
d4 <- rowSums(apply(irf4, 1, MVPLN.dfev, h=12, m=4))/100000
d5 <- rowSums(apply(irf5, 1, MVPLN.dfev, h=12, m=4))/100000

rm(irf1,irf2,irf3,irf4,irf5)
gc(); gc()


# Here's how we get it back into the proper array!

d1 <- array(100*d1, c(12, 4, 4))
d2 <- array(100*d2, c(12, 4, 4))
d3 <- array(100*d3, c(12, 4, 4))
d4 <- array(100*d4, c(12, 4, 4))
d5 <- array(100*d5, c(12, 4, 4))

# Now plot out all of the dfevs
pal <- c("black", "red", "blue", "green")
nm <- c("O", "M", "B", "P")

pdf(file="dfev.pdf", width=9, height=6.5)
par(mfcol=c(4,5), mai=c(0.25, 0.25, 0.15, 0.25),
    omi=c(0.15, 0.75, 1, 0.15))
for(i in 1:m)
{
    plot(ts(d1[,,i]), plot.type="single", col=pal, xlab="",
         ylab="", ylim=c(0,100), lwd=2)
    mtext(nm[i], side=2, line=3)
    if(i==1) mtext("1968:1-1973:1", side=3, line=1, cex=0.8)
}

for(i in 1:m)
{
    plot(ts(d2[,,i]), plot.type="single", col=pal, xlab="",
          ylim=c(0,100), lwd=2)
    if(i==1) mtext("1973:2-1979:12", side=3, line=1, cex=0.8)
}

for(i in 1:m)
{
    plot(ts(d3[,,i]), plot.type="single", col=pal, xlab="",
          ylim=c(0,100), lwd=2)
    if(i==1) mtext("1980:1-1989:11", side=3, line=1, cex=0.8)
}

for(i in 1:m)
{
    plot(ts(d4[,,i]), plot.type="single", col=pal, xlab="",
          ylim=c(0,100), lwd=2)
    if(i==1) mtext("1989:12-2001:9", side=3, line=1, cex=0.8)
}

for(i in 1:m)
{
    plot(ts(d5[,,i]), plot.type="single", col=pal, xlab="",
          ylim=c(0,100), lwd=2)
    if(i==1) mtext("2001:10-2008:12", side=3, line=1, cex=0.8)
}

mtext("Response in", side=2, line=3, outer=TRUE)
mtext("Subsample", side=3, line=3, outer=TRUE)
dev.off()

save.image("MVPLN-VAR-dfev.RData")

q(save="no")
