# MVPLN-VAR-monthly-posterior.R
#
# Posterior analysis for the output of the MVPLN-VAR*.R results
#
# Patrick T. Brandt
#
# 20091005 : Initial Version
# 20100713 : Revised to work on updated model specifications

# Load libraries
library(coda)

# Load the posterior sample
load("MVPLN-VAR-monthly.RData")

# Function to compute the summary measures for the two chains for each of the
# models.  Note that we need to subset the output since we have
# redundant entries for the symmetric covariance and the correlation
# matrix of the errors.  This will make the gelman.diag() computation
# fail because it uses a matrix decomposition that will be singular
# unless we do this subsetting.

# This is the subset for a VAR(1) model
ss <- c(1:16, 33:36, 38:40, 43:44, 48)

diagnostics <- function(x, ss)
{
    tmp1 <- summary(x)
    tmp2 <- gelman.diag(x[,ss])

    return(list(tmp1,tmp2))
}


# Load the posterior samples and then check the model statistics
load("MVPLN-monthly-1-1.RData")
print(d1 <- diagnostics(x2, ss))
rm(x2)

load("MVPLN-monthly-2-1.RData")
print(d2 <- diagnostics(x2, ss))
rm(x2)

load("MVPLN-monthly-3-1.RData")
print(d3 <- diagnostics(x2, ss))
rm(x2)

load("MVPLN-monthly-4-1.RData")
print(d4 <- diagnostics(x2, ss))
rm(x2)

load("MVPLN-monthly-5-1.RData")
print(d5 <- diagnostics(x2, ss))
rm(x2)

q(save="no")


